==> OCplus_1.14.0.zip: OCplus/doc/OCplus.R <==
###################################################
### chunk number 1: 
###################################################
options(width=65)


###################################################
### chunk number 2: 
###################################################
library(OCplus)


###################################################
### chunk number 3: 
###################################################
ss1 = samplesize(p0=0.95, D=1, crit=0.01)


###################################################
### chunk number 4: 
###################################################
ss1


###################################################
### chunk number 5: 
###################################################
samplesize(p0=0.95, D=1, crit=0.01)


###################################################
### chunk number 6: 
###################################################
TOC(n=20, p0=0.95, D=1, alpha=FALSE, legend=TRUE)


###################################################
### chunk number 7: 
###################################################
set.seed(123)
simdat = MAsim(ng=10000, n=10, p0=0.95, D=1, sigma=1)
dim(simdat)
colnames(simdat)


###################################################
### chunk number 8: 
###################################################
sim1 = EOC(simdat, colnames(simdat))
sim1[1:5,]


###################################################
### chunk number 9: 
###################################################
topDE(sim1, co=0.1)


###################################################
### chunk number 10: 
###################################################
p0(sim1)


###################################################
### chunk number 11: 
###################################################
plot(sim1)


###################################################
### chunk number 12: 
###################################################
sim2 = fdr1d(simdat, colnames(simdat), verb=FALSE)
sim2[1:5,]


###################################################
### chunk number 13: 
###################################################
summary(sim2)


###################################################
### chunk number 14: 
###################################################
topDE(sim2, co=0.1)


###################################################
### chunk number 15: 
###################################################
plot(sim2)


###################################################
### chunk number 16: 
###################################################
sim3 = fdr2d(simdat, colnames(simdat), p0=p0(sim2), verb=FALSE)
sim3[1:5,]


###################################################
### chunk number 17: 
###################################################
plot(sim2)
lines(average.fdr(sim3), lty=2)


###################################################
### chunk number 18: 
###################################################
summary(sim3)
topDE(sim3, co=0.1)


###################################################
### chunk number 19: 
###################################################
plot(sim3)


###################################################
### chunk number 20: 
###################################################
OCshow(sim1, sim2, sim3, legend=c("FDR","fdr1d","fdr2d"))


###################################################
### chunk number 21: 
###################################################
tt = tstatistics(simdat, colnames(simdat))
tt[1:10,] 
tm = tMixture(tt, nq=3)


###################################################
### chunk number 22: 
###################################################
tm$p0.est


###################################################
### chunk number 23: 
###################################################
tMixture(tt, nq=3, p0=0.80)$p0.est
tMixture(tt, nq=3, p0=0.60)$p0.est


###################################################
### chunk number 24: 
###################################################
tm2 = tMixture(tt, nq=5)
tm2$p0.est
tm2$p0.raw


###################################################
### chunk number 25: 
###################################################
tm2$p1
tm2$delta

==> OCplus_1.24.0.zip: OCplus/doc/OCplus.R <==
###################################################
### chunk number 1: 
###################################################
#line 45 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
options(width=65)


###################################################
### chunk number 2: 
###################################################
#line 66 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
library(OCplus)


###################################################
### chunk number 3: 
###################################################
#line 75 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
ss1 = samplesize(p0=0.95, D=1, crit=0.01)


###################################################
### chunk number 4: 
###################################################
#line 79 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
ss1


###################################################
### chunk number 5: 
###################################################
#line 88 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
samplesize(p0=0.95, D=1, crit=0.01)


###################################################
### chunk number 6: 
###################################################
#line 101 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
TOC(n=20, p0=0.95, D=1, alpha=FALSE, legend=TRUE)


###################################################
### chunk number 7: 
###################################################
#line 113 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
set.seed(123)
simdat = MAsim(ng=10000, n=10, p0=0.95, D=1, sigma=1)
dim(simdat)
colnames(simdat)


###################################################
### chunk number 8: 
###################################################
#line 125 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
sim1 = EOC(simdat, colnames(simdat))
sim1[1:5,]


###################################################
### chunk number 9: 
###################################################
#line 132 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
topDE(sim1, co=0.1)


###################################################
### chunk number 10: 
###################################################
#line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
p0(sim1)


###################################################
### chunk number 11: 
###################################################
#line 144 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
plot(sim1)


###################################################
### chunk number 12: 
###################################################
#line 154 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
sim2 = fdr1d(simdat, colnames(simdat), verb=FALSE)
sim2[1:5,]


###################################################
### chunk number 13: 
###################################################
#line 161 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
summary(sim2)


###################################################
### chunk number 14: 
###################################################
#line 167 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
topDE(sim2, co=0.1)


###################################################
### chunk number 15: 
###################################################
#line 173 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
plot(sim2)


###################################################
### chunk number 16: 
###################################################
#line 184 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
sim3 = fdr2d(simdat, colnames(simdat), p0=p0(sim2), verb=FALSE)
sim3[1:5,]


###################################################
### chunk number 17: 
###################################################
#line 194 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
plot(sim2)
lines(average.fdr(sim3), lty=2)


###################################################
### chunk number 18: 
###################################################
#line 203 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
summary(sim3)
topDE(sim3, co=0.1)


###################################################
### chunk number 19: 
###################################################
#line 212 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
plot(sim3)


###################################################
### chunk number 20: 
###################################################
#line 226 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
OCshow(sim1, sim2, sim3, legend=c("FDR","fdr1d","fdr2d"))


###################################################
### chunk number 21: 
###################################################
#line 237 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
tt = tstatistics(simdat, colnames(simdat))
tt[1:10,] 
tm = tMixture(tt, nq=3)


###################################################
### chunk number 22: 
###################################################
#line 243 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
tm$p0.est


###################################################
### chunk number 23: 
###################################################
#line 247 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
tMixture(tt, nq=3, p0=0.80)$p0.est
tMixture(tt, nq=3, p0=0.60)$p0.est


###################################################
### chunk number 24: 
###################################################
#line 254 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
tm2 = tMixture(tt, nq=5)
tm2$p0.est
tm2$p0.raw


###################################################
### chunk number 25: 
###################################################
#line 260 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgjSzcZ/R.INSTALL1163cd9/OCplus/inst/doc/OCplus.Rnw"
tm2$p1
tm2$delta
